use crate::constants::{SECRET_MINIO_BUCKET_ACCESS_LEN, SECRET_MINIO_BUCKET_SECRET_LEN};
use crate::utils::rand_str;

#[derive(Debug, Clone)]
pub struct MinioService {
    pub hostname: String,
    pub access_key: String,
    pub secret_key: String,
}

#[derive(Debug, Clone)]
pub struct MinioUser {
    pub username: String,
    pub password: String,
}

impl MinioUser {
    pub fn gen_random() -> Self {
        Self {
            username: rand_str(SECRET_MINIO_BUCKET_ACCESS_LEN),
            password: rand_str(SECRET_MINIO_BUCKET_SECRET_LEN),
        }
    }
}

impl MinioService {
    /// Check if the Minio Service is ready to respond to our requests
    pub async fn is_ready(&self) -> bool {
        match reqwest::get(format!("{}/minio/health/live", self.hostname)).await {
            Ok(r) => {
                if r.status() == 200 {
                    log::info!("Minio is ready!");
                    return true;
                }

                log::info!(
                    "Minio not ready yet, check failed with status code {}",
                    r.status()
                );
            }
            Err(e) => log::info!("Minio not ready yet, check failed with error {e}"),
        }

        false
    }
}
